<script setup>
import { ref } from "vue";
const trainType = ref("K");
const k_seat_type = ref("118座");
const k_seat_number = ref(1);
const k_seats_window = {
  "118座": [1, 4, 5, 9, 10, 14, 15, 19, 20, 24, 25, 29, 30, 34, 35, 39, 40, 44, 45, 49, 50, 54, 55, 59, 60, 64, 65, 69, 70, 74, 75, 79, 80, 84, 85, 89, 90, 94, 95, 99, 100, 104, 105, 109, 110, 114, 115, 118],
  "112座": [1, 3, 5, 8, 9, 13, 14, 18, 19, 23, 24, 28, 29, 33, 34, 38, 39, 43, 44, 48, 49, 53, 54, 58, 59, 63, 64, 68, 69, 73, 74, 78, 79, 83, 84, 88, 89, 93, 94, 98, 99, 103, 104, 108, 109, 112],
};
const g_seat_type = ref("二等座");
const g_seat_suffix = ref("A");
</script>

<template>
  <div class="min-h-screen bg-gray-50 py-12 px-4 sm:px-6 lg:px-8">
    <h1 class="text-2xl font-bold text-gray-800 mb-4 text-center">火车座位靠窗查询</h1>
    <div class="flex justify-center space-x-8 mb-8">
      <div class="flex items-center text-gray-600">
        <svg class="w-5 h-5 text-green-500 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
          <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7"></path>
        </svg>
        <span>完全免费</span>
      </div>
      <div class="flex items-center text-gray-600">
        <svg class="w-5 h-5 text-blue-500 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
          <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M13 10V3L4 14h7v7l9-11h-7z"></path>
        </svg>
        <span>快速查询</span>
      </div>
      <div class="flex items-center text-gray-600">
        <svg class="w-5 h-5 text-purple-500 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
          <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M9 12l2 2 4-4m5.618-4.016A11.955 11.955 0 0112 2.944a11.955 11.955 0 01-8.618 3.04A12.02 12.02 0 003 9c0 5.591 3.824 10.29 9 11.622 5.176-1.332 9-6.03 9-11.622 0-1.042-.133-2.052-.382-3.016z"></path>
        </svg>
        <span>准确可靠</span>
      </div>
    </div>
    <div class="max-w-md mx-auto bg-white rounded-xl shadow-lg p-8">
      <div class="space-y-6">
        <div class="space-y-2">
          <label class="block text-sm font-bold text-gray-700">火车类型</label>
          <select class="w-full bg-white border border-gray-300 rounded-lg p-3 focus:ring-2 focus:ring-blue-500 focus:border-blue-500 transition-all shadow-sm hover:border-blue-400" v-model="trainType">
            <option value="" disabled selected>请选择火车类型</option>
            <option value="N">纯数字 普通</option>
            <option value="K">K字头 快车</option>
            <option value="Z">Z字头 直达</option>
            <option value="C">C字头 城际</option>
            <option value="T">T字头 特快</option>
            <option value="D">D字头 动车</option>
            <option value="G">G字头 高铁</option>
          </select>
        </div>

        <div v-if="['K', 'T', 'N'].includes(trainType)" class="space-y-6">
          <div class="space-y-3">
            <label class="block text-sm font-bold text-gray-700">座位类型</label>
            <div class="conductor-info bg-gray-50 p-4 rounded-lg border border-gray-200">
              <p class="text-sm text-gray-600 mb-2"><span class="font-medium text-gray-800">长途车：</span>列车长办公室在<span class="font-medium text-blue-600">8号</span>车厢</p>
              <p class="text-sm text-gray-600"><span class="font-medium text-gray-800">短途车：</span>列车长办公室在<span class="font-medium text-blue-600">5号</span>车厢</p>
            </div>
            <select class="w-full bg-white border border-gray-300 rounded-lg p-3 focus:ring-2 focus:ring-blue-500 focus:border-blue-500 transition-all shadow-sm hover:border-blue-400" v-model="k_seat_type">
              <option value="118座">无列车长办公室</option>
              <option value="112座">有列车长办公室</option>
            </select>
          </div>

          <div class="space-y-3">
            <label class="block text-sm font-bold text-gray-700">座位号</label>
            <input type="number" v-model.number="k_seat_number" class="w-full bg-white border border-gray-300 rounded-lg p-3 focus:ring-2 focus:ring-blue-500 focus:border-blue-500 transition-all shadow-sm hover:border-blue-400" placeholder="请输入座位号" min="1" />
          </div>

          <div v-if="k_seat_type && k_seat_number" class="mt-4 p-4 rounded-lg" :class="k_seats_window[k_seat_type].includes(k_seat_number) ? 'bg-green-50 text-green-700 border border-green-200' : 'bg-red-50 text-red-700 border border-red-200'">
            <div class="flex items-center justify-center">
              <span class="text-xl mr-2">{{ k_seats_window[k_seat_type].includes(k_seat_number) ? "✓" : "✗" }}</span>
              <span>{{ k_seats_window[k_seat_type].includes(k_seat_number) ? "此座位靠窗" : "此座位不是靠窗" }}</span>
            </div>
          </div>
        </div>

        <div v-else-if="['D', 'G'].includes(trainType)" class="space-y-6">
          <div>
            <div class="space-y-3">
              <label class="block text-sm font-bold text-gray-700">座位号</label>
              <div class="flex space-x-6 justify-between px-6 bg-gray-50 py-4 rounded-lg border border-gray-200">
                <label v-for="suffix in ['A', 'B', 'C', 'D', 'F']" :key="suffix" class="inline-flex items-center group cursor-pointer">
                  <input type="radio" v-model="g_seat_suffix" :value="suffix" class="form-radio h-5 w-5 text-blue-600 border-2 border-gray-300 focus:ring-blue-500 transition duration-150 ease-in-out" />
                  <span class="ml-2 text-gray-700 group-hover:text-blue-600 transition-colors duration-150 font-medium">{{ suffix }}</span>
                </label>
              </div>
            </div>
            <div v-if="g_seat_suffix" class="mt-4 p-4 rounded-lg" :class="['A', 'F'].includes(g_seat_suffix) ? 'bg-green-50 text-green-700 border border-green-200' : 'bg-red-50 text-red-700 border border-red-200'">
              <div class="flex items-center justify-center">
                <span class="text-xl mr-2">{{ ["A", "F"].includes(g_seat_suffix) ? "✓" : "✗" }}</span>
                <span>{{ ["A", "F"].includes(g_seat_suffix) ? "此座位靠窗" : "此座位不是靠窗" }}</span>
              </div>
            </div>
          </div>
        </div>

        <div v-else>
          <div class="mt-6 p-4 rounded-lg text-center font-medium bg-red-50 text-red-800 border border-red-200">暂不支持</div>
        </div>
      </div>
    </div>
  </div>
</template>

<style scoped>
.conductor-info {
  padding: 12px;
  background-color: #f5f5f5;
  border-radius: 8px;
  margin: 10px 0;
}
.conductor-info p {
  margin: 8px 0;
  color: #333;
  font-size: 15px;
}
.train-type {
  font-weight: bold;
  color: #1976d2;
}
.carriage-number {
  color: #e53935;
  font-weight: bold;
}
</style>
